Learn R Programming

loadeR (version 1.2.0)

labels_loadeR: Returns a vector of keys to translate with tr.

Description

Returns a vector of keys to translate with tr.

Usage

labels_loadeR()

Arguments

Value

a vector of keys.

Author

Diego Jimenez <diego.jimenez@promidat.com>

Examples

Run this code
labels_loadeR()

Run the code above in your browser using DataLab