Learn R Programming

loadeR (version 1.2.0)

translation.loadeR: Returns a list of sentences with their translation in different languages.

Description

Returns a list of sentences with their translation in different languages.

Usage

translation.loadeR()

Arguments

Value

a list of sentences with their translation in different languages.

Author

Diego Jimenez <diego.jimenez@promidat.com>

Examples

Run this code
translation.loadeR()

Run the code above in your browser using DataLab