powered by
Returns a list of sentences with their translation in different languages.
translation.loadeR()
a list of sentences with their translation in different languages.
Diego Jimenez <diego.jimenez@promidat.com>
Run the code above in your browser using DataLab